summaryrefslogtreecommitdiffstats
path: root/bibletime/frontend/display
diff options
context:
space:
mode:
Diffstat (limited to 'bibletime/frontend/display')
-rw-r--r--bibletime/frontend/display/cdisplay.cpp44
-rw-r--r--bibletime/frontend/display/cdisplay.h46
-rw-r--r--bibletime/frontend/display/chtmlreaddisplay.cpp104
-rw-r--r--bibletime/frontend/display/chtmlreaddisplay.h50
-rw-r--r--bibletime/frontend/display/chtmlwritedisplay.cpp54
-rw-r--r--bibletime/frontend/display/chtmlwritedisplay.h20
-rw-r--r--bibletime/frontend/display/cplainwritedisplay.cpp46
-rw-r--r--bibletime/frontend/display/cplainwritedisplay.h30
-rw-r--r--bibletime/frontend/display/creaddisplay.cpp10
-rw-r--r--bibletime/frontend/display/creaddisplay.h12
-rw-r--r--bibletime/frontend/display/cwritedisplay.cpp2
-rw-r--r--bibletime/frontend/display/cwritedisplay.h2
12 files changed, 210 insertions, 210 deletions
diff --git a/bibletime/frontend/display/cdisplay.cpp b/bibletime/frontend/display/cdisplay.cpp
index ce97e02..f4f5f04 100644
--- a/bibletime/frontend/display/cdisplay.cpp
+++ b/bibletime/frontend/display/cdisplay.cpp
@@ -20,9 +20,9 @@
//Qt includes
-#include <qclipboard.h>
-#include <qpopupmenu.h>
-#include <qtimer.h>
+#include <tqclipboard.h>
+#include <tqpopupmenu.h>
+#include <tqtimer.h>
//KDE includes
#include <kapplication.h>
@@ -45,12 +45,12 @@ void CDisplayConnections::saveAsPlain() {
}
/** Emits the signal. */
-void CDisplayConnections::emitReferenceClicked( const QString& module, const QString& key) {
+void CDisplayConnections::emitReferenceClicked( const TQString& module, const TQString& key) {
emit referenceClicked( module, key );
}
/** Emits the signal. */
-void CDisplayConnections::emitReferenceDropped( const QString& key) {
+void CDisplayConnections::emitReferenceDropped( const TQString& key) {
emit referenceDropped(key);
}
@@ -94,7 +94,7 @@ void CDisplayConnections::saveAnchorWithText() {
}
void CDisplayConnections::clear() {
- m_display->setText(QString::null);
+ m_display->setText(TQString::null);
}
void CDisplayConnections::zoomIn() {
@@ -112,11 +112,11 @@ void CDisplayConnections::openFindTextDialog() {
/*----------------------*/
-CReadDisplay* CDisplay::createReadInstance( CReadWindow* readWindow, QWidget* parent ) {
+CReadDisplay* CDisplay::createReadInstance( CReadWindow* readWindow, TQWidget* parent ) {
return new CHTMLReadDisplay(readWindow, parent);
}
-CWriteDisplay* CDisplay::createWriteInstance( CWriteWindow* writeWindow, const CWriteDisplay::WriteDisplayType& type, QWidget* parent ) {
+CWriteDisplay* CDisplay::createWriteInstance( CWriteWindow* writeWindow, const CWriteDisplay::WriteDisplayType& type, TQWidget* parent ) {
// qWarning("CDisplay::createWriteInstance");
if (type == PlainTextDisplay) {
return new CPlainWriteDisplay(writeWindow, parent);
@@ -137,7 +137,7 @@ CDisplay::~CDisplay() {
}
const bool CDisplay::copy( const CDisplay::TextType format, const CDisplay::TextPart part ) {
- const QString content = text(format, part);
+ const TQString content = text(format, part);
QClipboard* cb = KApplication::clipboard();
cb->setText(content);
@@ -146,19 +146,19 @@ const bool CDisplay::copy( const CDisplay::TextType format, const CDisplay::Text
const bool CDisplay::save( const CDisplay::TextType format, const CDisplay::TextPart part ) {
// qWarning("CDisplay::save( const CDisplay::TextType format, const CDisplay::TextPart part )");
- const QString content = text(format, part);
- QString filter = QString::null;
+ const TQString content = text(format, part);
+ TQString filter = TQString::null;
switch (format) {
case HTMLText:
- filter = QString("*.html *.htm | ") + i18n("HTML files") + QString("\n *.* | All files (*.*)");
+ filter = TQString("*.html *.htm | ") + i18n("HTML files") + TQString("\n *.* | All files (*.*)");
break;
case PlainText:
- filter = QString("*.txt | ") + i18n("Text files") + QString("\n *.* | All files (*.*)");
+ filter = TQString("*.txt | ") + i18n("Text files") + TQString("\n *.* | All files (*.*)");
break;
};
- const QString filename = KFileDialog::getSaveFileName(QString::null, filter, 0, i18n("Save document ..."));
+ const TQString filename = KFileDialog::getSaveFileName(TQString::null, filter, 0, i18n("Save document ..."));
if (!filename.isEmpty()) {
CToolClass::savePlainFile(filename, content);
@@ -167,10 +167,10 @@ const bool CDisplay::save( const CDisplay::TextType format, const CDisplay::Text
}
/** Emits the signal which used when a reference was clicked. */
-void CDisplay::emitReferenceClicked( const QString& reference ) {
+void CDisplay::emitReferenceClicked( const TQString& reference ) {
qWarning("reference clicked %s", reference.latin1());
- QString module;
- QString key;
+ TQString module;
+ TQString key;
CReferenceManager::Type type;
/*const bool ok = */
CReferenceManager::decodeHyperlink(reference, module, key, type);
@@ -181,9 +181,9 @@ void CDisplay::emitReferenceClicked( const QString& reference ) {
}
/** Used when a reference was dropped onto the widget. */
-void CDisplay::emitReferenceDropped( const QString& reference ) {
- QString module;
- QString key;
+void CDisplay::emitReferenceDropped( const TQString& reference ) {
+ TQString module;
+ TQString key;
CReferenceManager::Type type;
/*const bool ok = */
CReferenceManager::decodeHyperlink(reference, module, key, type);
@@ -204,12 +204,12 @@ CDisplayWindow* const CDisplay::parentWindow() const {
}
/** Installs the popup which should be opened when the right mouse button was pressed. */
-void CDisplay::installPopup( QPopupMenu* popup ) {
+void CDisplay::installPopup( TQPopupMenu* popup ) {
m_popup = popup;
}
/** Returns the popup menu which was set by installPopupMenu() */
-QPopupMenu* const CDisplay::installedPopup() {
+TQPopupMenu* const CDisplay::installedPopup() {
Q_ASSERT(m_popup);
return m_popup;
}
diff --git a/bibletime/frontend/display/cdisplay.h b/bibletime/frontend/display/cdisplay.h
index d37692c..1d34f9e 100644
--- a/bibletime/frontend/display/cdisplay.h
+++ b/bibletime/frontend/display/cdisplay.h
@@ -17,9 +17,9 @@
#include "backend/cswordbackend.h"
//Qt includes
-#include <qobject.h>
-#include <qstring.h>
-#include <qmap.h>
+#include <tqobject.h>
+#include <tqstring.h>
+#include <tqmap.h>
class CDisplayConnections;
@@ -31,7 +31,7 @@ class CReadDisplay;
class CWriteDisplay;
-class QPopupMenu;
+class TQPopupMenu;
/** The base class for all display widgets.
* @author The BibleTime team
@@ -43,8 +43,8 @@ public:
PlainTextDisplay
};
- static CReadDisplay* createReadInstance(CReadWindow* readWindow, QWidget* parent = 0);
- static CWriteDisplay* createWriteInstance( CWriteWindow* writeWindow, const WriteDisplayType& type = PlainTextDisplay, QWidget* parent = 0 );
+ static CReadDisplay* createReadInstance(CReadWindow* readWindow, TQWidget* parent = 0);
+ static CWriteDisplay* createWriteInstance( CWriteWindow* writeWindow, const WriteDisplayType& type = PlainTextDisplay, TQWidget* parent = 0 );
enum TextType {
HTMLText, /* Used for HTML markup */
@@ -72,11 +72,11 @@ public:
/** Returns the text in the given format.
*
*/
- virtual const QString text( const CDisplay::TextType format = CDisplay::HTMLText, const CDisplay::TextPart part = CDisplay::Document ) = 0;
+ virtual const TQString text( const CDisplay::TextType format = CDisplay::HTMLText, const CDisplay::TextPart part = CDisplay::Document ) = 0;
/**
* Sets the new text for this display widget.
*/
- virtual void setText( const QString& newText ) = 0;
+ virtual void setText( const TQString& newText ) = 0;
/**
* Returns true if the display widget has a selection. Otherwise false.
*/
@@ -84,7 +84,7 @@ public:
/**
* Returns the view of this display widget.
*/
- virtual QWidget* view() = 0;
+ virtual TQWidget* view() = 0;
/**
* Selects the document text.
*/
@@ -101,11 +101,11 @@ public:
/**
* Installs the popup which should be opened when the right mouse button was pressed.
*/
- void installPopup( QPopupMenu* popup );
+ void installPopup( TQPopupMenu* popup );
/**
* Returns the popup menu which was set by installPopupMenu()
*/
- QPopupMenu* const installedPopup();
+ TQPopupMenu* const installedPopup();
virtual void zoomIn() {}
virtual void zoomOut() {}
@@ -116,19 +116,19 @@ public:
};
- virtual QMap<NodeInfoType, QString> getCurrentNodeInfo() {
- return QMap<NodeInfoType, QString>();
+ virtual TQMap<NodeInfoType, TQString> getCurrentNodeInfo() {
+ return TQMap<NodeInfoType, TQString>();
}
protected:
/**
* Used when a reference was dropped onto the widget.
*/
- void emitReferenceDropped( const QString& reference );
+ void emitReferenceDropped( const TQString& reference );
/**
* Emits the signal which used when a reference was clicked.
*/
- void emitReferenceClicked( const QString& reference );
+ void emitReferenceClicked( const TQString& reference );
protected:
CDisplay(CDisplayWindow* parent);
@@ -137,18 +137,18 @@ protected:
private:
CDisplayWindow* m_parentWindow;
CDisplayConnections* m_connections;
- QPopupMenu* m_popup;
+ TQPopupMenu* m_popup;
};
-class CDisplayConnections : public QObject {
+class CDisplayConnections : public TQObject {
Q_OBJECT
public:
CDisplayConnections( CDisplay* parent );
public slots:
virtual void selectAll();
- void emitReferenceClicked( const QString& module, const QString& key);
- void emitReferenceDropped( const QString& key );
+ void emitReferenceClicked( const TQString& module, const TQString& key);
+ void emitReferenceDropped( const TQString& key );
void emitTextChanged();
//stuff which works in every CDisplay
@@ -173,16 +173,16 @@ public slots:
void openFindTextDialog();
signals:
- void referenceClicked(const QString& module, const QString& key);
- void referenceDropped(const QString& key);
+ void referenceClicked(const TQString& module, const TQString& key);
+ void referenceDropped(const TQString& key);
void textChanged();
private:
CDisplay* m_display;
struct {
- QString module;
- QString key;
+ TQString module;
+ TQString key;
} m_referenceClickedCache;
};
diff --git a/bibletime/frontend/display/chtmlwritedisplay.cpp b/bibletime/frontend/display/chtmlwritedisplay.cpp
index e535f26..b1206f8 100644
--- a/bibletime/frontend/display/chtmlwritedisplay.cpp
+++ b/bibletime/frontend/display/chtmlwritedisplay.cpp
@@ -16,8 +16,8 @@
#include "util/cresmgr.h"
//Qt includes
-#include <qpopupmenu.h>
-#include <qtooltip.h>
+#include <tqpopupmenu.h>
+#include <tqtooltip.h>
//KDE includes
#include <kaction.h>
@@ -27,7 +27,7 @@
#include <kcolorbutton.h>
#include <kpopupmenu.h>
-CHTMLWriteDisplay::CHTMLWriteDisplay(CWriteWindow* parentWindow, QWidget* parent)
+CHTMLWriteDisplay::CHTMLWriteDisplay(CWriteWindow* parentWindow, TQWidget* parent)
: CPlainWriteDisplay(parentWindow,parent) {
m_actions.bold = 0;
m_actions.italic = 0;
@@ -41,15 +41,15 @@ CHTMLWriteDisplay::CHTMLWriteDisplay(CWriteWindow* parentWindow, QWidget* parent
CHTMLWriteDisplay::~CHTMLWriteDisplay() {}
-void CHTMLWriteDisplay::setText( const QString& newText ) {
- QString text = newText;
+void CHTMLWriteDisplay::setText( const TQString& newText ) {
+ TQString text = newText;
// text.replace("\n<br/><!-- BT newline -->\n", "\n");
- QTextEdit::setText(text);
+ TQTextEdit::setText(text);
}
-const QString CHTMLWriteDisplay::plainText() {
- return QTextEdit::text();
+const TQString CHTMLWriteDisplay::plainText() {
+ return TQTextEdit::text();
};
void CHTMLWriteDisplay::toggleBold() {
@@ -110,17 +110,17 @@ void CHTMLWriteDisplay::slotAlignmentChanged( int a ) {
/** Is called when a new color was selected. */
-void CHTMLWriteDisplay::slotColorSelected( const QColor& c) {
+void CHTMLWriteDisplay::slotColorSelected( const TQColor& c) {
setColor( c );
}
/** Is called when a text with another color was selected. */
-void CHTMLWriteDisplay::slotColorChanged(const QColor& c) {
+void CHTMLWriteDisplay::slotColorChanged(const TQColor& c) {
m_colorButton->setColor(c);
}
-void CHTMLWriteDisplay::slotFontChanged( const QFont& font ) {
+void CHTMLWriteDisplay::slotFontChanged( const TQFont& font ) {
m_actions.fontChooser->setFont( font.family() );
m_actions.fontSizeChooser->setFontSize( font.pointSize() );
@@ -138,7 +138,7 @@ void CHTMLWriteDisplay::setupToolbar(KToolBar * bar, KActionCollection * actions
m_actions.fontChooser->setToolTip( CResMgr::displaywindows::writeWindow::fontFamily::tooltip );
m_actions.fontChooser->plug(bar);
- connect(m_actions.fontChooser, SIGNAL(activated(const QString&)), this, SLOT(setFamily(const QString&)));
+ connect(m_actions.fontChooser, TQT_SIGNAL(activated(const TQString&)), this, TQT_SLOT(setFamily(const TQString&)));
m_actions.fontSizeChooser = new KFontSizeAction( i18n("Choose a font size"),
@@ -149,12 +149,12 @@ void CHTMLWriteDisplay::setupToolbar(KToolBar * bar, KActionCollection * actions
m_actions.fontSizeChooser->setToolTip( CResMgr::displaywindows::writeWindow::fontSize::tooltip );
m_actions.fontSizeChooser->plug(bar);
- connect(m_actions.fontSizeChooser, SIGNAL(fontSizeChanged(int)), this, SLOT(setPointSize(int)));
+ connect(m_actions.fontSizeChooser, TQT_SIGNAL(fontSizeChanged(int)), this, TQT_SLOT(setPointSize(int)));
m_colorButton = new KColorButton(bar);
- connect(m_colorButton, SIGNAL(changed(const QColor&)), this, SLOT(slotColorSelected(const QColor&)));
+ connect(m_colorButton, TQT_SIGNAL(changed(const TQColor&)), this, TQT_SLOT(slotColorSelected(const TQColor&)));
bar->insertWidget(50, m_colorButton->sizeHint().width(), m_colorButton);
- QToolTip::add
+ TQToolTip::add
(m_colorButton, CResMgr::displaywindows::writeWindow::fontColor::tooltip );
@@ -164,7 +164,7 @@ void CHTMLWriteDisplay::setupToolbar(KToolBar * bar, KActionCollection * actions
m_actions.bold = new KToggleAction( i18n("Bold"),
CResMgr::displaywindows::writeWindow::boldText::icon,
CResMgr::displaywindows::writeWindow::boldText::accel,
- this, SLOT(toggleBold()),
+ this, TQT_SLOT(toggleBold()),
actions,
CResMgr::displaywindows::writeWindow::boldText::actionName
);
@@ -175,7 +175,7 @@ void CHTMLWriteDisplay::setupToolbar(KToolBar * bar, KActionCollection * actions
m_actions.italic = new KToggleAction( i18n("Italic"),
CResMgr::displaywindows::writeWindow::italicText::icon,
CResMgr::displaywindows::writeWindow::italicText::accel,
- this, SLOT(toggleItalic()),
+ this, TQT_SLOT(toggleItalic()),
actions,
CResMgr::displaywindows::writeWindow::italicText::actionName
);
@@ -186,7 +186,7 @@ void CHTMLWriteDisplay::setupToolbar(KToolBar * bar, KActionCollection * actions
m_actions.underline = new KToggleAction( i18n("Underline"),
CResMgr::displaywindows::writeWindow::underlinedText::icon,
CResMgr::displaywindows::writeWindow::underlinedText::accel,
- this, SLOT(toggleUnderline()),
+ this, TQT_SLOT(toggleUnderline()),
actions,
CResMgr::displaywindows::writeWindow::underlinedText::actionName
);
@@ -200,7 +200,7 @@ void CHTMLWriteDisplay::setupToolbar(KToolBar * bar, KActionCollection * actions
m_actions.alignLeft = new KToggleAction( i18n("Left"),
CResMgr::displaywindows::writeWindow::alignLeft::icon,
CResMgr::displaywindows::writeWindow::alignLeft::accel,
- this, SLOT( alignLeft() ),
+ this, TQT_SLOT( alignLeft() ),
actions,
CResMgr::displaywindows::writeWindow::alignLeft::actionName
);
@@ -211,7 +211,7 @@ void CHTMLWriteDisplay::setupToolbar(KToolBar * bar, KActionCollection * actions
m_actions.alignCenter = new KToggleAction( i18n("Center"),
CResMgr::displaywindows::writeWindow::alignCenter::icon,
CResMgr::displaywindows::writeWindow::alignCenter::accel,
- this, SLOT(alignCenter()),
+ this, TQT_SLOT(alignCenter()),
actions,
CResMgr::displaywindows::writeWindow::alignCenter::actionName
);
@@ -222,7 +222,7 @@ void CHTMLWriteDisplay::setupToolbar(KToolBar * bar, KActionCollection * actions
m_actions.alignRight = new KToggleAction( i18n("Right"),
CResMgr::displaywindows::writeWindow::alignRight::icon,
CResMgr::displaywindows::writeWindow::alignRight::accel,
- this, SLOT(alignRight()),
+ this, TQT_SLOT(alignRight()),
actions,
CResMgr::displaywindows::writeWindow::alignRight::actionName
);
@@ -233,7 +233,7 @@ void CHTMLWriteDisplay::setupToolbar(KToolBar * bar, KActionCollection * actions
// m_actions.alignJustify = new KToggleAction( i18n("Justify"),
// CResMgr::displaywindows::writeWindow::alignJustify::icon,
// CResMgr::displaywindows::writeWindow::alignJustify::accel,
- // this, SLOT( alignJustify() ),
+ // this, TQT_SLOT( alignJustify() ),
// actions
// );
// m_actions.alignJustify->setToolTip( CResMgr::displaywindows::writeWindow::alignJustify::tooltip );
@@ -241,9 +241,9 @@ void CHTMLWriteDisplay::setupToolbar(KToolBar * bar, KActionCollection * actions
// m_actions.alignJustify->plug(bar);
- connect(this, SIGNAL(currentFontChanged(const QFont&)), SLOT(slotFontChanged(const QFont&)));
- connect(this, SIGNAL(currentAlignmentChanged(int)), SLOT(slotAlignmentChanged(int)));
- connect(this, SIGNAL(currentColorChanged(const QColor&)), SLOT(slotColorChanged(const QColor&)));
+ connect(this, TQT_SIGNAL(currentFontChanged(const TQFont&)), TQT_SLOT(slotFontChanged(const TQFont&)));
+ connect(this, TQT_SIGNAL(currentAlignmentChanged(int)), TQT_SLOT(slotAlignmentChanged(int)));
+ connect(this, TQT_SIGNAL(currentColorChanged(const TQColor&)), TQT_SLOT(slotColorChanged(const TQColor&)));
//set initial values for toolbar items
@@ -253,9 +253,9 @@ void CHTMLWriteDisplay::setupToolbar(KToolBar * bar, KActionCollection * actions
}
/** Reimplementation to show a popup menu if the right mouse butoon was clicked. */
-QPopupMenu* CHTMLWriteDisplay::createPopupMenu( const QPoint& /*pos*/ ) {
+TQPopupMenu* CHTMLWriteDisplay::createPopupMenu( const TQPoint& /*pos*/ ) {
if (!m_actions.selectAll) {
- m_actions.selectAll = new KAction(i18n("Select all"), KShortcut(0), this, SLOT(selectAll()), this);
+ m_actions.selectAll = new KAction(i18n("Select all"), KShortcut(0), this, TQT_SLOT(selectAll()), this);
}
KPopupMenu* popup = new KPopupMenu(this);
diff --git a/bibletime/frontend/display/chtmlwritedisplay.h b/bibletime/frontend/display/chtmlwritedisplay.h
index ad5faa6..4d9a508 100644
--- a/bibletime/frontend/display/chtmlwritedisplay.h
+++ b/bibletime/frontend/display/chtmlwritedisplay.h
@@ -16,12 +16,12 @@
#include "cplainwritedisplay.h"
//Qt includes
-#include <qwidget.h>
-#include <qtextedit.h>
+#include <tqwidget.h>
+#include <tqtextedit.h>
class CWriteWindow;
-class QPopupMenu;
+class TQPopupMenu;
class KToggleAction;
class KFontAction;
@@ -38,11 +38,11 @@ public:
/**
* Sets the new text for this display widget.
*/
- virtual void setText( const QString& newText );
+ virtual void setText( const TQString& newText );
/**
* Returns the text of this edit widget.
*/
- virtual const QString plainText();
+ virtual const TQString plainText();
/**
* Creates the necessary action objects and puts them on the toolbar.
@@ -51,12 +51,12 @@ public:
protected:
friend class CDisplay;
- CHTMLWriteDisplay(CWriteWindow* parentWindow, QWidget* parent);
+ CHTMLWriteDisplay(CWriteWindow* parentWindow, TQWidget* parent);
~CHTMLWriteDisplay();
/**
* Reimplementation to show a popup menu if the right mouse butoon was clicked.
*/
- virtual QPopupMenu* createPopupMenu( const QPoint& pos );
+ virtual TQPopupMenu* createPopupMenu( const TQPoint& pos );
protected slots:
void toggleBold();
@@ -67,7 +67,7 @@ protected slots:
void alignCenter();
void alignRight();
- void slotFontChanged( const QFont& );
+ void slotFontChanged( const TQFont& );
/**
* The text's alignment changed. Enable the right buttons.
*/
@@ -75,11 +75,11 @@ protected slots:
/**
* Is called when a new color was selected.
*/
- void slotColorSelected( const QColor& );
+ void slotColorSelected( const TQColor& );
/**
* Is called when a text with another color was selected.
*/
- void slotColorChanged( const QColor& );
+ void slotColorChanged( const TQColor& );
private:
struct {
diff --git a/bibletime/frontend/display/creaddisplay.cpp b/bibletime/frontend/display/creaddisplay.cpp
index 24c4f76..22baf24 100644
--- a/bibletime/frontend/display/creaddisplay.cpp
+++ b/bibletime/frontend/display/creaddisplay.cpp
@@ -29,25 +29,25 @@
#include "util/scoped_resource.h"
//Qt includes
-#include <qpopupmenu.h>
+#include <tqpopupmenu.h>
//KDE includes
#include <klocale.h>
CReadDisplay::CReadDisplay(CReadWindow* readWindow) :
CDisplay(readWindow),
-m_activeAnchor(QString::null),
+m_activeAnchor(TQString::null),
m_useMouseTracking(true) {}
CReadDisplay::~CReadDisplay() {}
/** Returns the current active anchor. */
-const QString& CReadDisplay::activeAnchor() {
+const TQString& CReadDisplay::activeAnchor() {
return m_activeAnchor;
}
/** Sets the current anchor to the parameter. */
-void CReadDisplay::setActiveAnchor( const QString& anchor ) {
+void CReadDisplay::setActiveAnchor( const TQString& anchor ) {
m_activeAnchor = anchor;
}
@@ -64,7 +64,7 @@ void CReadDisplay::print(const CDisplay::TextPart type, CSwordBackend::DisplayOp
CSwordModuleInfo* module = key->module();
- CExportManager mgr(i18n("Print keys"),false, QString::null, parentWindow()->filterOptions(), parentWindow()->displayOptions());
+ CExportManager mgr(i18n("Print keys"),false, TQString::null, parentWindow()->filterOptions(), parentWindow()->displayOptions());
switch (type) {
case Document: {
diff --git a/bibletime/frontend/display/creaddisplay.h b/bibletime/frontend/display/creaddisplay.h
index de3e51d..48ce7b0 100644
--- a/bibletime/frontend/display/creaddisplay.h
+++ b/bibletime/frontend/display/creaddisplay.h
@@ -15,8 +15,8 @@
#include "cdisplay.h"
#include "backend/cswordbackend.h"
-class QPopupMenu;
-class QWidget;
+class TQPopupMenu;
+class TQWidget;
/**The base class for all read-only widgets like KHTMLView.
*@author The BibleTime team
@@ -31,11 +31,11 @@ public:
/**
* Returns the current active anchor.
*/
- const QString& activeAnchor();
+ const TQString& activeAnchor();
/**
* Moves the widget to the given anchor.
*/
- virtual void moveToAnchor( const QString& ) = 0;
+ virtual void moveToAnchor( const TQString& ) = 0;
virtual void print(const CDisplay::TextPart, CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions);
void setMouseTracking(const bool trackingEnabled) {
@@ -56,14 +56,14 @@ protected: // Protected methods
/**
* Sets the current anchor to the parameter.
*/
- void setActiveAnchor( const QString& );
+ void setActiveAnchor( const TQString& );
private: // Public attributes
/**
* The member which hols the current anchor.
*/
- QString m_activeAnchor;
+ TQString m_activeAnchor;
bool m_useMouseTracking;
};
diff --git a/bibletime/frontend/display/cwritedisplay.cpp b/bibletime/frontend/display/cwritedisplay.cpp
index 1c3ad4e..33c0926 100644
--- a/bibletime/frontend/display/cwritedisplay.cpp
+++ b/bibletime/frontend/display/cwritedisplay.cpp
@@ -15,7 +15,7 @@
#include "frontend/displaywindow/cwritewindow.h"
//Qt includes
-#include <qwidget.h>
+#include <tqwidget.h>
CWriteDisplay::CWriteDisplay( CWriteWindow* writeWindow ) : CDisplay(writeWindow) {}
diff --git a/bibletime/frontend/display/cwritedisplay.h b/bibletime/frontend/display/cwritedisplay.h
index b1222e8..f33b4d7 100644
--- a/bibletime/frontend/display/cwritedisplay.h
+++ b/bibletime/frontend/display/cwritedisplay.h
@@ -40,7 +40,7 @@ public: // Public methods
/**
* Returns the text of this edit widget.
*/
- virtual const QString plainText() = 0;
+ virtual const TQString plainText() = 0;
/**
* Creates the necessary action objects and puts them on the toolbar.
*/
diff --git a/bibletime/frontend/display/chtmlreaddisplay.cpp b/bibletime/frontend/display/chtmlreaddisplay.cpp
index 4219f33..60e3e58 100644
--- a/bibletime/frontend/display/chtmlreaddisplay.cpp
+++ b/bibletime/frontend/display/chtmlreaddisplay.cpp
@@ -28,16 +28,16 @@
#include <kdeversion.h>
//Qt includes
-#include <qcursor.h>
-#include <qscrollview.h>
-#include <qwidget.h>
-#include <qdragobject.h>
-#include <qpopupmenu.h>
-#include <qlayout.h>
-#include <qtimer.h>
+#include <tqcursor.h>
+#include <tqscrollview.h>
+#include <tqwidget.h>
+#include <tqdragobject.h>
+#include <tqpopupmenu.h>
+#include <tqlayout.h>
+#include <tqtimer.h>
#if KDE_VERSION < 0x030300
//We will need to show the error message.
-#include <qmessagebox.h>
+#include <tqmessagebox.h>
#endif
//KDE includes
@@ -52,10 +52,10 @@
using namespace InfoDisplay;
-CHTMLReadDisplay::CHTMLReadDisplay(CReadWindow* readWindow, QWidget* parentWidget)
+CHTMLReadDisplay::CHTMLReadDisplay(CReadWindow* readWindow, TQWidget* parentWidget)
: KHTMLPart((m_view = new CHTMLReadDisplayView(this, parentWidget ? parentWidget : readWindow)), readWindow ? readWindow : parentWidget),
CReadDisplay(readWindow),
-m_currentAnchorCache(QString::null) {
+m_currentAnchorCache(TQString::null) {
setDNDEnabled(false);
setJavaEnabled(false);
setJScriptEnabled(false);
@@ -67,7 +67,7 @@ m_currentAnchorCache(QString::null) {
CHTMLReadDisplay::~CHTMLReadDisplay() {}
-const QString CHTMLReadDisplay::text( const CDisplay::TextType format, const CDisplay::TextPart part) {
+const TQString CHTMLReadDisplay::text( const CDisplay::TextType format, const CDisplay::TextPart part) {
switch (part) {
case Document: {
@@ -95,7 +95,7 @@ const QString CHTMLReadDisplay::text( const CDisplay::TextType format, const CDi
CPointers::backend()->setFilterOptions(filterOptions);
- return QString(key->strippedText()).append("\n(")
+ return TQString(key->strippedText()).append("\n(")
.append(key->key())
.append(", ")
.append(key->module()->name())
@@ -106,7 +106,7 @@ const QString CHTMLReadDisplay::text( const CDisplay::TextType format, const CDi
case SelectedText: {
if (!hasSelection()) {
- return QString::null;
+ return TQString::null;
}
else if (format == HTMLText) {
DOM::Range range = selection();
@@ -118,8 +118,8 @@ const QString CHTMLReadDisplay::text( const CDisplay::TextType format, const CDi
}
case AnchorOnly: {
- QString moduleName;
- QString keyName;
+ TQString moduleName;
+ TQString keyName;
CReferenceManager::Type type;
CReferenceManager::decodeHyperlink(activeAnchor(), moduleName, keyName, type);
@@ -127,8 +127,8 @@ const QString CHTMLReadDisplay::text( const CDisplay::TextType format, const CDi
}
case AnchorTextOnly: {
- QString moduleName;
- QString keyName;
+ TQString moduleName;
+ TQString keyName;
CReferenceManager::Type type;
CReferenceManager::decodeHyperlink(activeAnchor(), moduleName, keyName, type);
@@ -138,12 +138,12 @@ const QString CHTMLReadDisplay::text( const CDisplay::TextType format, const CDi
return key->strippedText();
}
- return QString::null;
+ return TQString::null;
}
case AnchorWithText: {
- QString moduleName;
- QString keyName;
+ TQString moduleName;
+ TQString keyName;
CReferenceManager::Type type;
CReferenceManager::decodeHyperlink(activeAnchor(), moduleName, keyName, type);
@@ -162,7 +162,7 @@ const QString CHTMLReadDisplay::text( const CDisplay::TextType format, const CDi
CPointers::backend()->setFilterOptions(filterOptions);
- return QString(key->strippedText()).append("\n(")
+ return TQString(key->strippedText()).append("\n(")
.append(key->key())
.append(", ")
.append(key->module()->name())
@@ -172,14 +172,14 @@ const QString CHTMLReadDisplay::text( const CDisplay::TextType format, const CDi
.arg(key->key())
.arg(key->module()->name());*/
}
- return QString::null;
+ return TQString::null;
}
default:
- return QString::null;
+ return TQString::null;
}
}
-void CHTMLReadDisplay::setText( const QString& newText ) {
+void CHTMLReadDisplay::setText( const TQString& newText ) {
begin();
write(newText);
end();
@@ -192,7 +192,7 @@ const bool CHTMLReadDisplay::hasSelection() {
/** Reimplementation. */
-QScrollView* CHTMLReadDisplay::view() {
+TQScrollView* CHTMLReadDisplay::view() {
return KHTMLPart::view();
}
@@ -201,23 +201,23 @@ void CHTMLReadDisplay::selectAll() {
}
/** No descriptions */
-void CHTMLReadDisplay::moveToAnchor( const QString& anchor ) {
+void CHTMLReadDisplay::moveToAnchor( const TQString& anchor ) {
m_currentAnchorCache = anchor;
//This is an ugly hack to work around a KDE problem in KDE including 3.3.1 (no later versions tested so far)
- QTimer::singleShot(0, this, SLOT(slotGoToAnchor()));
+ TQTimer::singleShot(0, this, TQT_SLOT(slotGoToAnchor()));
// instead of:
// slotGoToAnchor();
}
-void CHTMLReadDisplay::urlSelected( const QString& url, int button, int state, const QString& _target, KParts::URLArgs args) {
+void CHTMLReadDisplay::urlSelected( const TQString& url, int button, int state, const TQString& _target, KParts::URLArgs args) {
KHTMLPart::urlSelected(url, button, state, _target, args);
m_urlWorkaroundData.doWorkaround = false;
// qWarning("clicked: %s", url.latin1());
if (!url.isEmpty() && CReferenceManager::isHyperlink(url)) {
- QString module;
- QString key;
+ TQString module;
+ TQString key;
CReferenceManager::Type type;
CReferenceManager::decodeHyperlink(url, module, key, type);
@@ -271,7 +271,7 @@ void CHTMLReadDisplay::khtmlMousePressEvent( khtml::MousePressEvent* event ) {
if (event->qmouseEvent()->button() == Qt::RightButton) {
DOM::Node tmpNode = event->innerNode();
DOM::Node attr;
- m_nodeInfo[CDisplay::Lemma] = QString::null;
+ m_nodeInfo[CDisplay::Lemma] = TQString::null;
do {
if (!tmpNode.isNull() && (tmpNode.nodeType() ==
@@ -292,7 +292,7 @@ void CHTMLReadDisplay::khtmlMousePressEvent( khtml::MousePressEvent* event ) {
m_dndData.anchor = event->url();
m_dndData.mousePressed = true;
m_dndData.isDragging = false;
- m_dndData.startPos = QPoint(event->x(), event->y());
+ m_dndData.startPos = TQPoint(event->x(), event->y());
m_dndData.selection = selectedText();
if (!m_dndData.node.isNull()) { //we drag a valid link
@@ -307,23 +307,23 @@ void CHTMLReadDisplay::khtmlMousePressEvent( khtml::MousePressEvent* event ) {
void CHTMLReadDisplay::khtmlMouseMoveEvent( khtml::MouseMoveEvent* e ) {
if( e->qmouseEvent()->state() & LeftButton == LeftButton) { //left mouse button pressed
const int delay = KGlobalSettings::dndEventDelay();
- QPoint newPos = QPoint(e->x(), e->y());
+ TQPoint newPos = TQPoint(e->x(), e->y());
if ( (newPos.x() > m_dndData.startPos.x()+delay || newPos.x() < (m_dndData.startPos.x()-delay) ||
newPos.y() > m_dndData.startPos.y()+delay || newPos.y() < (m_dndData.startPos.y()-delay)) &&
!m_dndData.isDragging && m_dndData.mousePressed ) {
- QDragObject* d = 0;
+ TQDragObject* d = 0;
if (!m_dndData.anchor.isEmpty() && (m_dndData.dragType == DNDData::Link) && !m_dndData.node.isNull() ) {
// create a new bookmark drag!
- QString module = QString::null;
- QString key = QString::null;
+ TQString module = TQString::null;
+ TQString key = TQString::null;
CReferenceManager::Type type;
if ( !CReferenceManager::decodeHyperlink(m_dndData.anchor.string(), module, key, type) )
return;
CDragDropMgr::ItemList dndItems;
//no description!
- dndItems.append( CDragDropMgr::Item(module, key, QString::null) );
+ dndItems.append( CDragDropMgr::Item(module, key, TQString::null) );
d = CDragDropMgr::dragObject(dndItems, KHTMLPart::view()->viewport());
}
else if ((m_dndData.dragType == DNDData::Text) && !m_dndData.selection.isEmpty()) {
@@ -338,7 +338,7 @@ void CHTMLReadDisplay::khtmlMouseMoveEvent( khtml::MouseMoveEvent* e ) {
m_dndData.mousePressed = false;
//first make a virtual mouse click to end the selection, it it's in progress
- QMouseEvent e(QEvent::MouseButtonRelease, QPoint(0,0), Qt::LeftButton, Qt::LeftButton);
+ TQMouseEvent e(TQEvent::MouseButtonRelease, TQPoint(0,0), Qt::LeftButton, Qt::LeftButton);
KApplication::sendEvent(view()->viewport(), &e);
d->drag();
}
@@ -353,7 +353,7 @@ void CHTMLReadDisplay::khtmlMouseMoveEvent( khtml::MouseMoveEvent* e ) {
// After some millisecs the new timer activates the Mag window update, see timerEvent()
// SHIFT key not pressed, so we start timer
if ( !(e->qmouseEvent()->state() & Qt::ShiftButton)) {
- // QObject has simple timer
+ // TQObject has simple timer
killTimers();
startTimer( CBTConfig::get(CBTConfig::magDelay) );
}
@@ -366,7 +366,7 @@ void CHTMLReadDisplay::khtmlMouseMoveEvent( khtml::MouseMoveEvent* e ) {
}
/** The Mag window update happens here if the mouse has not moved to another node after starting the timer.*/
-void CHTMLReadDisplay::timerEvent( QTimerEvent *e ) {
+void CHTMLReadDisplay::timerEvent( TQTimerEvent *e ) {
killTimers();
DOM::Node currentNode = nodeUnderMouse();
CInfoDisplay::ListInfoData infoList;
@@ -422,7 +422,7 @@ void CHTMLReadDisplay::timerEvent( QTimerEvent *e ) {
// ---------------------
-CHTMLReadDisplayView::CHTMLReadDisplayView(CHTMLReadDisplay* displayWidget, QWidget* parent) : KHTMLView(displayWidget, parent), m_display(displayWidget) {
+CHTMLReadDisplayView::CHTMLReadDisplayView(CHTMLReadDisplay* displayWidget, TQWidget* parent) : KHTMLView(displayWidget, parent), m_display(displayWidget) {
viewport()->setAcceptDrops(true);
setMarginWidth(4);
setMarginHeight(4);
@@ -430,24 +430,24 @@ CHTMLReadDisplayView::CHTMLReadDisplayView(CHTMLReadDisplay* displayWidget, QWid
/** Opens the popupmenu at the given position. */
-void CHTMLReadDisplayView::popupMenu( const QString& url, const QPoint& pos) {
+void CHTMLReadDisplayView::popupMenu( const TQString& url, const TQPoint& pos) {
if (!url.isEmpty()) {
m_display->setActiveAnchor(url);
}
- if (QPopupMenu* popup = m_display->installedPopup()) {
+ if (TQPopupMenu* popup = m_display->installedPopup()) {
popup->exec(pos);
}
}
/** Reimplementation from QScrollView. Sets the right slots */
void CHTMLReadDisplayView::polish() {
KHTMLView::polish();
- connect( part(), SIGNAL(popupMenu(const QString&, const QPoint&)),
- this, SLOT(popupMenu(const QString&, const QPoint&)));
+ connect( part(), TQT_SIGNAL(popupMenu(const TQString&, const TQPoint&)),
+ this, TQT_SLOT(popupMenu(const TQString&, const TQPoint&)));
}
-/** Reimplementatiob from QScrollView. */
-void CHTMLReadDisplayView::contentsDropEvent( QDropEvent* e ) {
+/** Reimplementatiob from TQScrollView. */
+void CHTMLReadDisplayView::contentsDropEvent( TQDropEvent* e ) {
if (CDragDropMgr::canDecode(e) && CDragDropMgr::dndType(e) == CDragDropMgr::Item::Bookmark) {
CDragDropMgr::ItemList dndItems = CDragDropMgr::decode(e);
CDragDropMgr::Item item = dndItems.first();
@@ -462,8 +462,8 @@ void CHTMLReadDisplayView::contentsDropEvent( QDropEvent* e ) {
e->ignore();
}
-/** Reimplementation from QScrollView. */
-void CHTMLReadDisplayView::contentsDragEnterEvent( QDragEnterEvent* e ) {
+/** Reimplementation from TQScrollView. */
+void CHTMLReadDisplayView::contentsDragEnterEvent( TQDragEnterEvent* e ) {
if (CDragDropMgr::canDecode(e) && CDragDropMgr::dndType(e) == CDragDropMgr::Item::Bookmark) {
e->acceptAction();
return;
@@ -482,7 +482,7 @@ void CHTMLReadDisplay::slotGoToAnchor() {
qDebug("anchor %s not present!", m_currentAnchorCache.latin1());
}
}
- m_currentAnchorCache = QString::null;
+ m_currentAnchorCache = TQString::null;
}
void CHTMLReadDisplay::zoomIn() {
@@ -497,7 +497,7 @@ void CHTMLReadDisplay::openFindTextDialog() {
#if KDE_VERSION >= 0x030300
findText();
#else
- QMessageBox::information(0, "Not Supported",
+ TQMessageBox::information(0, "Not Supported",
"This copy of BibleTime was built against a version of KDE older\n"
"than 3.3 (probably due to your distro), so this search feature\n"
"does not work.\n\n"
@@ -430,24 +430,24 @@ CHTMLReadDisplayView::CHTMLReadDisplayView(CHTMLReadDisplay* displayWidget, QWid
}
}
-/** Reimplementation from QScrollView. Sets the right slots */
+/** Reimplementation from TQScrollView. Sets the right slots */
void CHTMLReadDisplayView::polish() {
KHTMLView::polish();
diff --git a/bibletime/frontend/display/chtmlreaddisplay.h b/bibletime/frontend/display/chtmlreaddisplay.h
index 5b875cf..3a4cb02 100644
--- a/bibletime/frontend/display/chtmlreaddisplay.h
+++ b/bibletime/frontend/display/chtmlreaddisplay.h
@@ -17,8 +17,8 @@
//#include "frontend/ctooltip.h"
//Qt includes
-#include <qstring.h>
-#include <qwidget.h>
+#include <tqstring.h>
+#include <tqwidget.h>
//KDE includes
#include <khtml_part.h>
@@ -37,40 +37,40 @@ public:
/**
* Returns the right text part in the specified format.
*/
- virtual const QString text( const CDisplay::TextType format = CDisplay::HTMLText, const CDisplay::TextPart part = CDisplay::Document );
+ virtual const TQString text( const CDisplay::TextType format = CDisplay::HTMLText, const CDisplay::TextPart part = CDisplay::Document );
/**
* Sets the new text for this display widget.
*/
- virtual void setText( const QString& newText );
+ virtual void setText( const TQString& newText );
virtual const bool hasSelection();
/**
* Reimplementation.
*/
- virtual QScrollView* view();
+ virtual TQScrollView* view();
virtual void selectAll();
- virtual void moveToAnchor( const QString& anchor );
+ virtual void moveToAnchor( const TQString& anchor );
virtual void zoomIn();
virtual void zoomOut();
virtual void openFindTextDialog();
- virtual QMap<CDisplay::NodeInfoType, QString> getCurrentNodeInfo() {
+ virtual TQMap<CDisplay::NodeInfoType, TQString> getCurrentNodeInfo() {
return m_nodeInfo;
}
protected:
friend class CDisplay;
- CHTMLReadDisplay( CReadWindow* readWindow, QWidget* parent = 0 );
+ CHTMLReadDisplay( CReadWindow* readWindow, TQWidget* parent = 0 );
virtual ~CHTMLReadDisplay();
- virtual void urlSelected( const QString& url, int button, int state, const QString& _target, KParts::URLArgs args);
+ virtual void urlSelected( const TQString& url, int button, int state, const TQString& _target, KParts::URLArgs args);
/**
* Reimplementation.
*/
virtual void khtmlMouseReleaseEvent( khtml::MouseReleaseEvent* event );
virtual void khtmlMousePressEvent( khtml::MousePressEvent* event );
virtual void khtmlMouseMoveEvent( khtml::MouseMoveEvent* event );
- virtual void timerEvent(QTimerEvent *event);
+ virtual void timerEvent(TQTimerEvent *event);
struct DNDData {
@@ -78,8 +78,8 @@ protected:
bool isDragging;
DOM::Node node;
DOM::DOMString anchor;
- QString selection;
- QPoint startPos;
+ TQString selection;
+ TQPoint startPos;
enum DragType {
Link,
Text
@@ -87,25 +87,25 @@ protected:
}
m_dndData;
- QMap<NodeInfoType, QString> m_nodeInfo;
+ TQMap<NodeInfoType, TQString> m_nodeInfo;
private:
CHTMLReadDisplayView* m_view;
struct URLWorkaroundData {
bool doWorkaround;
- QString url;
+ TQString url;
int button;
int state;
- QString target;
+ TQString target;
KParts::URLArgs args;
- QString module;
- QString key;
+ TQString module;
+ TQString key;
}
m_urlWorkaroundData;
DOM::Node m_previousEventNode;
- QString m_currentAnchorCache;
+ TQString m_currentAnchorCache;
protected slots:
void slotGoToAnchor();
@@ -117,25 +117,25 @@ protected: // Protected methods
friend class CHTMLReadDisplay;
- CHTMLReadDisplayView(CHTMLReadDisplay* display, QWidget* parent);
+ CHTMLReadDisplayView(CHTMLReadDisplay* display, TQWidget* parent);
/**
* Reimplementation from QScrollView. Sets the right slots
*/
virtual void polish();
/**
* Reimplementatiob from QScrollView.
*/
- virtual void contentsDropEvent( QDropEvent* );
+ virtual void contentsDropEvent( TQDropEvent* );
/**
* Reimplementatiob from QScrollView.
*/
- virtual void contentsDragEnterEvent( QDragEnterEvent* );
+ virtual void contentsDragEnterEvent( TQDragEnterEvent* );
protected slots: // Protected slots
/**
* Opens the popupmenu at the given position.
*/
- void popupMenu( const QString&, const QPoint& );
+ void popupMenu( const TQString&, const TQPoint& );
private:
CHTMLReadDisplay* m_display;
@@ -117,25 +117,25 @@ protected: // Protected methods
/**
- * Reimplementation from QScrollView. Sets the right slots
+ * Reimplementation from TQScrollView. Sets the right slots
*/
virtual void polish();
@@ -117,25 +117,25 @@ protected: // Protected methods
virtual void polish();
/**
- * Reimplementatiob from QScrollView.
+ * Reimplementatiob from TQScrollView.
*/
@@ -117,25 +117,25 @@ protected: // Protected methods
/**
- * Reimplementatiob from QScrollView.
+ * Reimplementatiob from TQScrollView.
*/
diff --git a/bibletime/frontend/display/cplainwritedisplay.cpp b/bibletime/frontend/display/cplainwritedisplay.cpp
index 2e81db0..7be7c6c 100644
--- a/bibletime/frontend/display/cplainwritedisplay.cpp
+++ b/bibletime/frontend/display/cplainwritedisplay.cpp
@@ -23,42 +23,42 @@
#include <kaction.h>
#include <klocale.h>
-CPlainWriteDisplay::CPlainWriteDisplay(CWriteWindow* parentWindow, QWidget* parent) : QTextEdit(parentWindow ? parentWindow : parent), CWriteDisplay(parentWindow) {
+CPlainWriteDisplay::CPlainWriteDisplay(CWriteWindow* parentWindow, TQWidget* parent) : TQTextEdit(parentWindow ? parentWindow : parent), CWriteDisplay(parentWindow) {
setTextFormat(Qt::PlainText);
setAcceptDrops(true);
viewport()->setAcceptDrops(true);
- connect(this, SIGNAL(textChanged()),
- connectionsProxy(), SLOT(emitTextChanged()));
+ connect(this, TQT_SIGNAL(textChanged()),
+ connectionsProxy(), TQT_SLOT(emitTextChanged()));
}
CPlainWriteDisplay::~CPlainWriteDisplay() {}
/** Reimplementation. */
void CPlainWriteDisplay::selectAll() {
- QTextEdit::selectAll(true);
+ TQTextEdit::selectAll(true);
}
-void CPlainWriteDisplay::setText( const QString& newText ) {
+void CPlainWriteDisplay::setText( const TQString& newText ) {
//make sure the text has been converted to show \n instead of <br/>
- QString text = newText;
+ TQString text = newText;
// text.replace("\n<br /><!-- BT newline -->\n", "\n");
text.replace("<br />", "\n"); //inserted by BT or the Qt textedit widget
- QTextEdit::setText(text);
+ TQTextEdit::setText(text);
}
const bool CPlainWriteDisplay::hasSelection() {
return hasSelectedText();
}
-QWidget* CPlainWriteDisplay::view() {
+TQWidget* CPlainWriteDisplay::view() {
qDebug("CPlainWriteDisplay::view()");
return this;
}
-const QString CPlainWriteDisplay::text( const CDisplay::TextType /*format*/, const CDisplay::TextPart /*part*/) {
- return QString::null;
+const TQString CPlainWriteDisplay::text( const CDisplay::TextType /*format*/, const CDisplay::TextPart /*part*/) {
+ return TQString::null;
}
void CPlainWriteDisplay::print( const CDisplay::TextPart, CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions ) {
@@ -66,18 +66,18 @@ void CPlainWriteDisplay::print( const CDisplay::TextPart, CSwordBackend::Display
/** Sets the current status of the edit widget. */
void CPlainWriteDisplay::setModified( const bool modified ) {
- QTextEdit::setModified(modified);
+ TQTextEdit::setModified(modified);
}
/** Reimplementation. */
const bool CPlainWriteDisplay::isModified() const {
- return QTextEdit::isModified();
+ return TQTextEdit::isModified();
}
/** Returns the text of this edit widget. */
-const QString CPlainWriteDisplay::plainText() {
- QString ret = QTextEdit::text();
+const TQString CPlainWriteDisplay::plainText() {
+ TQString ret = TQTextEdit::text();
//in plain text mode the text just contains newlines, convert them into <br/> before we return the text for display in a HTML widget
ret.replace("\n", "<br />");
@@ -85,13 +85,13 @@ const QString CPlainWriteDisplay::plainText() {
return ret;
}
-/** Reimplementation from QTextEdit. Provides an popup menu for the given position. */
-QPopupMenu* CPlainWriteDisplay::createPopupMenu( const QPoint& /*pos*/ ) {
+/** Reimplementation from TQTextEdit. Provides an popup menu for the given position. */
+TQPopupMenu* CPlainWriteDisplay::createPopupMenu( const TQPoint& /*pos*/ ) {
return installedPopup();
}
-/** Reimplementation from QTextEdit. Provides an popup menu for the given position. */
-QPopupMenu* CPlainWriteDisplay::createPopupMenu( ) {
+/** Reimplementation from TQTextEdit. Provides an popup menu for the given position. */
+TQPopupMenu* CPlainWriteDisplay::createPopupMenu( ) {
return installedPopup();
}
@@ -99,7 +99,7 @@ QPopupMenu* CPlainWriteDisplay::createPopupMenu( ) {
void CPlainWriteDisplay::setupToolbar(KToolBar* /*bar*/, KActionCollection* /*actionCollection*/) {}
/** Reimplementation to insert the text of a dragged reference into the edit view. */
-void CPlainWriteDisplay::contentsDragEnterEvent( QDragEnterEvent* e ) {
+void CPlainWriteDisplay::contentsDragEnterEvent( TQDragEnterEvent* e ) {
if (CDragDropMgr::canDecode(e)) {
e->accept(true);
}
@@ -110,7 +110,7 @@ void CPlainWriteDisplay::contentsDragEnterEvent( QDragEnterEvent* e ) {
}
/** Reimplementation to insert the text of a dragged reference into the edit view. */
-void CPlainWriteDisplay::contentsDragMoveEvent( QDragMoveEvent* e ) {
+void CPlainWriteDisplay::contentsDragMoveEvent( TQDragMoveEvent* e ) {
if (CDragDropMgr::canDecode(e)) {
placeCursor(e->pos());
ensureCursorVisible();
@@ -123,7 +123,7 @@ void CPlainWriteDisplay::contentsDragMoveEvent( QDragMoveEvent* e ) {
}
/** Reimplementation to manage drops of our drag and drop objects. */
-void CPlainWriteDisplay::contentsDropEvent( QDropEvent* e ) {
+void CPlainWriteDisplay::contentsDropEvent( TQDropEvent* e ) {
if ( CDragDropMgr::canDecode(e) ) {
e->acceptAction();
@@ -136,9 +136,9 @@ void CPlainWriteDisplay::contentsDropEvent( QDropEvent* e ) {
util::scoped_ptr<CSwordKey> key( CSwordKey::createInstance(module) );
key->key( (*it).bookmarkKey() );
- QString moduleText = key->strippedText();
+ TQString moduleText = key->strippedText();
- const QString text = QString::fromLatin1("%1\n(%2, %3)\n").arg(moduleText).arg((*it).bookmarkKey()).arg((*it).bookmarkModule());
+ const TQString text = TQString::fromLatin1("%1\n(%2, %3)\n").arg(moduleText).arg((*it).bookmarkKey()).arg((*it).bookmarkModule());
placeCursor( e->pos() );
insert( text );
diff --git a/bibletime/frontend/display/cplainwritedisplay.h b/bibletime/frontend/display/cplainwritedisplay.h
index 9219578..546d05c 100644
--- a/bibletime/frontend/display/cplainwritedisplay.h
+++ b/bibletime/frontend/display/cplainwritedisplay.h
@@ -16,8 +16,8 @@
#include "cwritedisplay.h"
//Qt includes
-#include <qwidget.h>
-#include <qtextedit.h>
+#include <tqwidget.h>
+#include <tqtextedit.h>
class CHTMLWriteDisplay;
class KAction;
@@ -25,7 +25,7 @@ class KAction;
/** The write display implementation for plain source code editing.
* @author The BibleTime team
*/
-class CPlainWriteDisplay : public QTextEdit, public CWriteDisplay {
+class CPlainWriteDisplay : public TQTextEdit, public CWriteDisplay {
public:
/**
* Reimplementation.
@@ -34,7 +34,7 @@ public:
/**
* Sets the new text for this display widget.
*/
- virtual void setText( const QString& newText );
+ virtual void setText( const TQString& newText );
/**
* Returns true if the display widget has a selection. Otherwise false.
*/
@@ -42,8 +42,8 @@ public:
/**
* Returns the view of this display widget.
*/
- virtual QWidget* view();
- virtual const QString text( const CDisplay::TextType format = CDisplay::HTMLText, const CDisplay::TextPart part = CDisplay::Document );
+ virtual TQWidget* view();
+ virtual const TQString text( const CDisplay::TextType format = CDisplay::HTMLText, const CDisplay::TextPart part = CDisplay::Document );
virtual void print( const CDisplay::TextPart, CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions );
/**
* Reimplementation.
@@ -56,7 +56,7 @@ public:
/**
* Returns the text of this edit widget.
*/
- virtual const QString plainText();
+ virtual const TQString plainText();
/**
* Creates the necessary action objects and puts them on the toolbar.
*/
@@ -66,28 +66,28 @@ protected:
friend class CDisplay;
friend class CHTMLWriteDisplay;
- CPlainWriteDisplay(CWriteWindow* parentWindow, QWidget* parent);
+ CPlainWriteDisplay(CWriteWindow* parentWindow, TQWidget* parent);
virtual ~CPlainWriteDisplay();
/**
* Reimplementation from QTextEdit. Provides an popup menu for the given position.
*/
- virtual QPopupMenu* createPopupMenu( const QPoint& pos );
+ virtual TQPopupMenu* createPopupMenu( const TQPoint& pos );
/**
* Reimplementation from QTextEdit. Provides an popup menu.
*/
- virtual QPopupMenu* createPopupMenu();
+ virtual TQPopupMenu* createPopupMenu();
/**
* Reimplementation to manage drops of our drag and drop objects.
*/
- virtual void contentsDropEvent( QDropEvent* e );
+ virtual void contentsDropEvent( TQDropEvent* e );
/**
* Reimplementation to insert the text of a dragged reference into the edit view.
*/
- virtual void contentsDragEnterEvent( QDragEnterEvent* e );
+ virtual void contentsDragEnterEvent( TQDragEnterEvent* e );
/**
* Reimplementation to insert the text of a dragged reference into the edit view.
*/
- virtual void contentsDragMoveEvent( QDragMoveEvent* e );
+ virtual void contentsDragMoveEvent( TQDragMoveEvent* e );
};
@@ -66,28 +66,28 @@ protected:
virtual ~CPlainWriteDisplay();
/**
- * Reimplementation from QTextEdit. Provides an popup menu for the given position.
+ * Reimplementation from TQTextEdit. Provides an popup menu for the given position.
*/
@@ -66,28 +66,28 @@ protected:
/**
- * Reimplementation from QTextEdit. Provides an popup menu.
+ * Reimplementation from TQTextEdit. Provides an popup menu.
*/